@@ -6,10 +6,11 @@ test_that("dv is numeric", {
   expect_that(aov_car(treatment ~ gender + Error(id/phase*hour), data = obk.long, observed = "gender"), throws_error("dv needs to be numeric."))
 })
 
-test_that("non Type 3 sums give warning", {
-  data(obk.long)
-  expect_that(aov_4(value ~ treatment * gender + (phase*hour|id), data = obk.long, observed = "gender", check.contrasts = FALSE), gives_warning("contrasts"))
-})
+## check_contrast argument disabled, see: https://github.com/singmann/afex/issues/109
+# test_that("non Type 3 sums give warning", {
+#   data(obk.long)
+#   expect_that(aov_4(value ~ treatment * gender + (phase*hour|id), data = obk.long, observed = "gender", check.contrasts = FALSE), gives_warning("contrasts"))
+# })
 
 test_that("return='aov' works", {
   data(obk.long)
@@ -134,9 +135,13 @@ test_that("error messages for common problems", {
   ]
   
   expect_error(
-    aov_car(value ~ treatment * gender + Error(id), data = obk2),
+    aov_car(value ~ treatment * gender + Error(id), data = obk2, 
+            fun_aggregate = mean),
     "between-subjects design")
   expect_error(
     aov_car(value ~ treatment * gender + Error(id/phase*hour), data = obk2),
     "between-subjects design")
+  expect_error(
+    aov_car(value ~ treatment * gender, data = obk2), 
+    "formula needs an error term")
 })
